Stan Math Library: stan/math/prim/scal/prob/hypergeometric_log.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
hypergeometric_log.hpp File Reference
`#include <stan/math/prim/scal/err/check_consistent_sizes.hpp>`
`#include <stan/math/prim/scal/err/check_bounded.hpp>`
`#include <stan/math/prim/scal/err/check_finite.hpp>`
`#include <stan/math/prim/scal/err/check_greater.hpp>`
`#include <stan/math/prim/scal/err/check_positive.hpp>`
`#include <stan/math/prim/scal/fun/binomial_coefficient_log.hpp>`
`#include <stan/math/prim/scal/meta/length.hpp>`
`#include <stan/math/prim/scal/meta/VectorView.hpp>`
`#include <stan/math/prim/scal/meta/VectorBuilder.hpp>`
`#include <stan/math/prim/scal/meta/return_type.hpp>`
`#include <stan/math/prim/scal/meta/include_summand.hpp>`
`#include <stan/math/prim/scal/fun/constants.hpp>`
`#include <boost/math/distributions.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<bool propto, typename T_n , typename T_N , typename T_a , typename T_b >
double | stan::math::hypergeometric_log (const T_n &n, const T_N &N, const T_a &a, const T_b &b)
template<typename T_n , typename T_N , typename T_a , typename T_b >
double | stan::math::hypergeometric_log (const T_n &n, const T_N &N, const T_a &a, const T_b &b)

[ Stan Home Page ] © 2011–2016, Stan Development Team.